==> dojo-1.10.6.tgz: package/cldr/nls/bs/islamic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yM": "MM.y. G",
	"field-dayperiod": "pre podne/ popodne",
	"dateFormatItem-yyyyMMMEd": "E, dd. MMM y. G",
	"dayPeriods-format-wide-pm": "popodne",
	"field-minute": "minut",
	"dateFormatItem-MMMEd": "E, dd. MMM",
	"field-day-relative+-1": "juče",
	"field-weekday": "dan u nedelji",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-yQQQ": "y G QQQ",
	"field-day-relative+-2": "prekjuče",
	"dateFormatItem-MMM": "LLL",
	"field-era": "era",
	"dateFormatItem-Gy": "y. G",
	"field-hour": "čas",
	"dayPeriods-format-wide-am": "pre podne",
	"dateFormatItem-y": "y. G",
	"dateFormatItem-yyyy": "y. G",
	"dateFormatItem-Ed": "E, dd.",
	"dateFormatItem-yMMM": "MMM y. G",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"eraAbbr": [
		"AH"
	],
	"field-day-relative+2": "prekosutra",
	"dateFormatItem-GyMMMd": "dd. MMM y. G",
	"dateFormat-long": "dd. MMMM y. G",
	"field-zone": "zona",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormat-medium": "dd.MM.y. G",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-yMd": "dd.MM.y. G",
	"dateFormatItem-ms": "mm:ss",
	"field-year": "godina",
	"field-week": "nedelja",
	"dateFormatItem-yyyyMd": "dd.MM.y. G",
	"dateFormatItem-yyyyMMMd": "dd. MMM y. G",
	"dateFormatItem-yyyyMEd": "E, dd.MM.y. G",
	"dateFormatItem-MMMd": "dd. MMM",
	"dateFormatItem-yQQQQ": "y G QQQQ",
	"field-month": "mesec",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-M": "L",
	"dateFormatItem-yMMMd": "dd. MMM y. G",
	"field-second": "sekund",
	"dateFormatItem-GyMMMEd": "E, dd. MMM y. G",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-day": "dan",
	"dateFormatItem-MEd": "E, dd.MM.",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormat-short": "dd.MM.y. G",
	"dateFormatItem-yyyyM": "MM.y. G",
	"dateFormatItem-yMMMEd": "E, dd. MMM y. G",
	"dateFormat-full": "EEEE, dd. MMMM y. G",
	"dateFormatItem-Md": "dd.MM.",
	"dateFormatItem-yMEd": "E, dd.MM.y. G",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"dateFormatItem-d": "d",
	"quarters-format-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	]
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/bs/islamic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yM": "MM.y. G",
	"field-dayperiod": "prijepodne/poslijepodne",
	"dateFormatItem-yyyyMMMEd": "E, dd. MMM y. G",
	"dayPeriods-format-wide-pm": "popodne",
	"field-minute": "minut",
	"dateFormatItem-MMMEd": "E, dd. MMM",
	"field-day-relative+-1": "juče",
	"field-weekday": "dan u sedmici",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-yQQQ": "y G QQQ",
	"field-day-relative+-2": "prekjuče",
	"dateFormatItem-MMM": "LLL",
	"field-era": "era",
	"dateFormatItem-Gy": "y. G",
	"field-hour": "sat",
	"dayPeriods-format-wide-am": "prije podne",
	"dateFormatItem-y": "y. G",
	"dateFormatItem-yyyy": "y. G",
	"dateFormatItem-Ed": "E, dd.",
	"dateFormatItem-yMMM": "MMM y. G",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"eraAbbr": [
		"AH"
	],
	"field-day-relative+2": "prekosutra",
	"dateFormatItem-GyMMMd": "dd. MMM y. G",
	"dateFormat-long": "dd. MMMM y. G",
	"field-zone": "zona",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormat-medium": "dd.MM.y. G",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-yMd": "dd.MM.y. G",
	"dateFormatItem-ms": "mm:ss",
	"field-year": "godina",
	"field-week": "sedmica",
	"dateFormatItem-yyyyMd": "dd.MM.y. G",
	"dateFormatItem-yyyyMMMd": "dd. MMM y. G",
	"dateFormatItem-yyyyMEd": "E, dd.MM.y. G",
	"dateFormatItem-MMMd": "dd. MMM",
	"dateFormatItem-yQQQQ": "y G QQQQ",
	"field-month": "mjesec",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-M": "L",
	"dateFormatItem-yMMMd": "dd. MMM y. G",
	"field-second": "sekund",
	"dateFormatItem-GyMMMEd": "E, dd. MMM y. G",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-day": "dan",
	"dateFormatItem-MEd": "E, dd.MM.",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormat-short": "dd.MM.y. G",
	"dateFormatItem-yyyyM": "MM.y. G",
	"dateFormatItem-yMMMEd": "E, dd. MMM y. G",
	"dateFormat-full": "EEEE, dd. MMMM y. G",
	"dateFormatItem-Md": "dd.MM.",
	"dateFormatItem-yMEd": "E, dd.MM.y. G",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"dateFormatItem-d": "d",
	"quarters-format-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	]
}
//end v1.x content
);
